==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/kubernetes/kotlin/inputs/ListConnectedClusterUserCredentialPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kubernetes.kotlin.inputs

import com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs.builder
import com.pulumi.azurenative.kubernetes.kotlin.enums.AuthenticationMethod
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property authenticationMethod The mode of client authentication.
 * @property clientProxy Boolean value to indicate whether the request is for client side proxy or not
 * @property clusterName The name of the Kubernetes cluster on which get is called.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListConnectedClusterUserCredentialPlainArgs(
    public val authenticationMethod: Either<String, AuthenticationMethod>,
    public val clientProxy: Boolean,
    public val clusterName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs =
        com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs.builder()
            .authenticationMethod(
                authenticationMethod.let({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .clientProxy(clientProxy.let({ args0 -> args0 }))
            .clusterName(clusterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListConnectedClusterUserCredentialPlainArgs].
 */
@PulumiTagMarker
public class ListConnectedClusterUserCredentialPlainArgsBuilder internal constructor() {
    private var authenticationMethod: Either<String, AuthenticationMethod>? = null

    private var clientProxy: Boolean? = null

    private var clusterName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The mode of client authentication.
     */
    @JvmName("xvompjpdjdnqeimj")
    public suspend fun authenticationMethod(`value`: Either<String, AuthenticationMethod>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.authenticationMethod = mapped
    }

    /**
     * @param value The mode of client authentication.
     */
    @JvmName("adjpvfkblrlijsqd")
    public fun authenticationMethod(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AuthenticationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.authenticationMethod = mapped
    }

    /**
     * @param value The mode of client authentication.
     */
    @JvmName("nwxyrfxgbtwmjyov")
    public fun authenticationMethod(`value`: AuthenticationMethod) {
        val toBeMapped = Either.ofRight<String, AuthenticationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.authenticationMethod = mapped
    }

    /**
     * @param value Boolean value to indicate whether the request is for client side proxy or not
     */
    @JvmName("dqnfqsjjwfdlelhf")
    public suspend fun clientProxy(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clientProxy = mapped
    }

    /**
     * @param value The name of the Kubernetes cluster on which get is called.
     */
    @JvmName("pjmawcojcxqcofsb")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("xkxqsuxsrlousqjo")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListConnectedClusterUserCredentialPlainArgs =
        ListConnectedClusterUserCredentialPlainArgs(
            authenticationMethod = authenticationMethod ?: throw
                PulumiNullFieldException("authenticationMethod"),
            clientProxy = clientProxy ?: throw PulumiNullFieldException("clientProxy"),
            clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/kubernetes/kotlin/inputs/ListConnectedClusterUserCredentialPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kubernetes.kotlin.inputs

import com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs.builder
import com.pulumi.azurenative.kubernetes.kotlin.enums.AuthenticationMethod
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property authenticationMethod The mode of client authentication.
 * @property clientProxy Boolean value to indicate whether the request is for client side proxy or not
 * @property clusterName The name of the Kubernetes cluster on which get is called.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListConnectedClusterUserCredentialPlainArgs(
    public val authenticationMethod: Either<String, AuthenticationMethod>,
    public val clientProxy: Boolean,
    public val clusterName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs =
        com.pulumi.azurenative.kubernetes.inputs.ListConnectedClusterUserCredentialPlainArgs.builder()
            .authenticationMethod(
                authenticationMethod.let({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .clientProxy(clientProxy.let({ args0 -> args0 }))
            .clusterName(clusterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListConnectedClusterUserCredentialPlainArgs].
 */
@PulumiTagMarker
public class ListConnectedClusterUserCredentialPlainArgsBuilder internal constructor() {
    private var authenticationMethod: Either<String, AuthenticationMethod>? = null

    private var clientProxy: Boolean? = null

    private var clusterName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The mode of client authentication.
     */
    @JvmName("qkrkosbbtjkcjrlm")
    public suspend fun authenticationMethod(`value`: Either<String, AuthenticationMethod>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.authenticationMethod = mapped
    }

    /**
     * @param value The mode of client authentication.
     */
    @JvmName("rlnnjrtliilwrgmn")
    public fun authenticationMethod(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AuthenticationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.authenticationMethod = mapped
    }

    /**
     * @param value The mode of client authentication.
     */
    @JvmName("ykbsjjsssxeuylcj")
    public fun authenticationMethod(`value`: AuthenticationMethod) {
        val toBeMapped = Either.ofRight<String, AuthenticationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.authenticationMethod = mapped
    }

    /**
     * @param value Boolean value to indicate whether the request is for client side proxy or not
     */
    @JvmName("aylbwttxxyqruved")
    public suspend fun clientProxy(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clientProxy = mapped
    }

    /**
     * @param value The name of the Kubernetes cluster on which get is called.
     */
    @JvmName("ksfgcwniquvekyjg")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("enidwtudmvuydtiw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListConnectedClusterUserCredentialPlainArgs =
        ListConnectedClusterUserCredentialPlainArgs(
            authenticationMethod = authenticationMethod ?: throw
                PulumiNullFieldException("authenticationMethod"),
            clientProxy = clientProxy ?: throw PulumiNullFieldException("clientProxy"),
            clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
